===========
pygameoflife
===========

A simple agent-based implementation of Conway's Game of Life.

Usage:
------

To run the programme just open a console and type either

    pygameoflife_console  

to run the simple command line version.

or

    pygameoflife_gui

to run a GTK+ version (requires pyGTK).
